# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/router/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.network_pb import Network
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.model import ClassMeta
from typing import Optional, List, Dict
from dataclasses import dataclass


@dataclass
class RoutingContext(ClassMeta):
    """
    RoutingContext is the context with information relative to routing process.
    It conforms to the structure of xray.features.routing.Context and xray.features.routing.Route.
    """
    InboundTag: Optional[str] = None
    Network: Optional[Network] = None
    SourceIPs: Optional[List[bytes]] = None
    TargetIPs: Optional[List[bytes]] = None
    SourcePort: Optional[int] = None
    TargetPort: Optional[int] = None
    TargetDomain: Optional[str] = None
    Protocol: Optional[str] = None
    User: Optional[str] = None
    Attributes: Optional[Dict[str, str]] = None
    OutboundGroupTags: Optional[List[str]] = None
    OutboundTag: Optional[str] = None


@dataclass
class SubscribeRoutingStatsRequest(ClassMeta):
    """
    SubscribeRoutingStatsRequest subscribes to routing statistics channel if opened by xray-core.

    * FieldSelectors selects a subset of fields in routing statistics to return.

    Valid selectors:
        - inbound: Selects connection's inbound tag.
        - network: Selects connection's network.
        - ip: Equivalent as "ip_source" and "ip_target", selects both source and target IP.
        - port: Equivalent as "port_source" and "port_target", selects both source and target port.
        - domain: Selects target domain.
        - protocol: Select connection's protocol.
        - user: Select connection's inbound user email.
        - attributes: Select connection's additional attributes.
        - outbound: Equivalent as "outbound" and "outbound_group", select both outbound tag and outbound group tags.
    * If FieldSelectors is left empty, all fields will be returned.
    """
    FieldSelectors: Optional[List[str]] = None


@dataclass
class TestRouteRequest(ClassMeta):
    """
    TestRouteRequest manually tests a routing result according to the routing context message.
        * RoutingContext is the routing message without outbound information.
        * FieldSelectors selects the fields to return in the routing result. All fields are returned if left empty.
        * PublishResult broadcasts the routing result to routing statistics channel if set true.
    """
    RoutingContext: Optional[RoutingContext] = None
    FieldSelectors: Optional[List[str]] = None
    PublishResult: Optional[bool] = None


@dataclass
class PrincipleTargetInfo(ClassMeta):
    tag: Optional[List[str]] = None


@dataclass
class OverrideInfo(ClassMeta):
    target: Optional[str] = None


@dataclass
class BalancerMsg(ClassMeta):
    override: Optional[OverrideInfo] = None
    principle_target: Optional[PrincipleTargetInfo] = None


@dataclass
class GetBalancerInfoRequest(ClassMeta):
    tag: Optional[str] = None


@dataclass
class GetBalancerInfoResponse(ClassMeta):
    balancer: Optional[BalancerMsg] = None


@dataclass
class OverrideBalancerTargetRequest(ClassMeta):
    balancerTag: Optional[str] = None
    target: Optional[str] = None


@dataclass
class OverrideBalancerTargetResponse(ClassMeta):
    pass


@dataclass
class AddRuleRequest(ClassMeta):
    config: Optional[TypedMessage] = None
    shouldAppend: Optional[bool] = None


@dataclass
class AddRuleResponse(ClassMeta):
    pass


@dataclass
class RemoveRuleRequest(ClassMeta):
    ruleTag: Optional[str] = None


@dataclass
class RemoveRuleResponse(ClassMeta):
    pass


@dataclass
class Config(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n+xcapi/xray/app/router/command/command.proto\x12\x17xray.app.router.command\x1a#xcapi/xray/common/net/network.proto\x1a,xcapi/xray/common/serial/typed_message.proto\"\x83\x03\n\x0eRoutingContext\x12\x12\n\nInboundTag\x18\x01 \x01(\t\x12)\n\x07Network\x18\x02 \x01(\x0e\x32\x18.xray.common.net.Network\x12\x11\n\tSourceIPs\x18\x03 \x03(\x0c\x12\x11\n\tTargetIPs\x18\x04 \x03(\x0c\x12\x12\n\nSourcePort\x18\x05 \x01(\r\x12\x12\n\nTargetPort\x18\x06 \x01(\r\x12\x14\n\x0cTargetDomain\x18\x07 \x01(\t\x12\x10\n\x08Protocol\x18\x08 \x01(\t\x12\x0c\n\x04User\x18\t \x01(\t\x12K\n\nAttributes\x18\n \x03(\x0b\x32\x37.xray.app.router.command.RoutingContext.AttributesEntry\x12\x19\n\x11OutboundGroupTags\x18\x0b \x03(\t\x12\x13\n\x0bOutboundTag\x18\x0c \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1cSubscribeRoutingStatsRequest\x12\x16\n\x0e\x46ieldSelectors\x18\x01 \x03(\t\"\x82\x01\n\x10TestRouteRequest\x12?\n\x0eRoutingContext\x18\x01 \x01(\x0b\x32\'.xray.app.router.command.RoutingContext\x12\x16\n\x0e\x46ieldSelectors\x18\x02 \x03(\t\x12\x15\n\rPublishResult\x18\x03 \x01(\x08\"\"\n\x13PrincipleTargetInfo\x12\x0b\n\x03tag\x18\x01 \x03(\t\"\x1e\n\x0cOverrideInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\"\x8e\x01\n\x0b\x42\x61lancerMsg\x12\x37\n\x08override\x18\x05 \x01(\x0b\x32%.xray.app.router.command.OverrideInfo\x12\x46\n\x10principle_target\x18\x06 \x01(\x0b\x32,.xray.app.router.command.PrincipleTargetInfo\"%\n\x16GetBalancerInfoRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\"Q\n\x17GetBalancerInfoResponse\x12\x36\n\x08\x62\x61lancer\x18\x01 \x01(\x0b\x32$.xray.app.router.command.BalancerMsg\"D\n\x1dOverrideBalancerTargetRequest\x12\x13\n\x0b\x62\x61lancerTag\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\" \n\x1eOverrideBalancerTargetResponse\"X\n\x0e\x41\x64\x64RuleRequest\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x14\n\x0cshouldAppend\x18\x02 \x01(\x08\"\x11\n\x0f\x41\x64\x64RuleResponse\"$\n\x11RemoveRuleRequest\x12\x0f\n\x07ruleTag\x18\x01 \x01(\t\"\x14\n\x12RemoveRuleResponse\"\x08\n\x06\x43onfig2\xbf\x05\n\x0eRoutingService\x12{\n\x15SubscribeRoutingStats\x12\x35.xray.app.router.command.SubscribeRoutingStatsRequest\x1a\'.xray.app.router.command.RoutingContext\"\x00\x30\x01\x12\x61\n\tTestRoute\x12).xray.app.router.command.TestRouteRequest\x1a\'.xray.app.router.command.RoutingContext\"\x00\x12v\n\x0fGetBalancerInfo\x12/.xray.app.router.command.GetBalancerInfoRequest\x1a\x30.xray.app.router.command.GetBalancerInfoResponse\"\x00\x12\x8b\x01\n\x16OverrideBalancerTarget\x12\x36.xray.app.router.command.OverrideBalancerTargetRequest\x1a\x37.xray.app.router.command.OverrideBalancerTargetResponse\"\x00\x12^\n\x07\x41\x64\x64Rule\x12\'.xray.app.router.command.AddRuleRequest\x1a(.xray.app.router.command.AddRuleResponse\"\x00\x12g\n\nRemoveRule\x12*.xray.app.router.command.RemoveRuleRequest\x1a+.xray.app.router.command.RemoveRuleResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.router.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ROUTINGCONTEXT_ATTRIBUTESENTRY']._loaded_options = None
    _globals['_ROUTINGCONTEXT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
    _globals['_ROUTINGCONTEXT']._serialized_start = 156
    _globals['_ROUTINGCONTEXT']._serialized_end = 543
    _globals['_ROUTINGCONTEXT_ATTRIBUTESENTRY']._serialized_start = 494
    _globals['_ROUTINGCONTEXT_ATTRIBUTESENTRY']._serialized_end = 543
    _globals['_SUBSCRIBEROUTINGSTATSREQUEST']._serialized_start = 545
    _globals['_SUBSCRIBEROUTINGSTATSREQUEST']._serialized_end = 599
    _globals['_TESTROUTEREQUEST']._serialized_start = 602
    _globals['_TESTROUTEREQUEST']._serialized_end = 732
    _globals['_PRINCIPLETARGETINFO']._serialized_start = 734
    _globals['_PRINCIPLETARGETINFO']._serialized_end = 768
    _globals['_OVERRIDEINFO']._serialized_start = 770
    _globals['_OVERRIDEINFO']._serialized_end = 800
    _globals['_BALANCERMSG']._serialized_start = 803
    _globals['_BALANCERMSG']._serialized_end = 945
    _globals['_GETBALANCERINFOREQUEST']._serialized_start = 947
    _globals['_GETBALANCERINFOREQUEST']._serialized_end = 984
    _globals['_GETBALANCERINFORESPONSE']._serialized_start = 986
    _globals['_GETBALANCERINFORESPONSE']._serialized_end = 1067
    _globals['_OVERRIDEBALANCERTARGETREQUEST']._serialized_start = 1069
    _globals['_OVERRIDEBALANCERTARGETREQUEST']._serialized_end = 1137
    _globals['_OVERRIDEBALANCERTARGETRESPONSE']._serialized_start = 1139
    _globals['_OVERRIDEBALANCERTARGETRESPONSE']._serialized_end = 1171
    _globals['_ADDRULEREQUEST']._serialized_start = 1173
    _globals['_ADDRULEREQUEST']._serialized_end = 1261
    _globals['_ADDRULERESPONSE']._serialized_start = 1263
    _globals['_ADDRULERESPONSE']._serialized_end = 1280
    _globals['_REMOVERULEREQUEST']._serialized_start = 1282
    _globals['_REMOVERULEREQUEST']._serialized_end = 1318
    _globals['_REMOVERULERESPONSE']._serialized_start = 1320
    _globals['_REMOVERULERESPONSE']._serialized_end = 1340
    _globals['_CONFIG']._serialized_start = 1342
    _globals['_CONFIG']._serialized_end = 1350
    _globals['_ROUTINGSERVICE']._serialized_start = 1353
    _globals['_ROUTINGSERVICE']._serialized_end = 2056



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.proxyman.command import command_pb


class HandlerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddInbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/AddInbound',
            request_serializer=command_pb.AddInboundRequest.SerializeToString,
            response_deserializer=command_pb.AddInboundResponse.FromString,
            _registered_method=True)
        self.RemoveInbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/RemoveInbound',
            request_serializer=command_pb.RemoveInboundRequest.SerializeToString,
            response_deserializer=command_pb.RemoveInboundResponse.FromString,
            _registered_method=True)
        self.AlterInbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/AlterInbound',
            request_serializer=command_pb.AlterInboundRequest.SerializeToString,
            response_deserializer=command_pb.AlterInboundResponse.FromString,
            _registered_method=True)
        self.AddOutbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/AddOutbound',
            request_serializer=command_pb.AddOutboundRequest.SerializeToString,
            response_deserializer=command_pb.AddOutboundResponse.FromString,
            _registered_method=True)
        self.RemoveOutbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/RemoveOutbound',
            request_serializer=command_pb.RemoveOutboundRequest.SerializeToString,
            response_deserializer=command_pb.RemoveOutboundResponse.FromString,
            _registered_method=True)
        self.AlterOutbound = channel.unary_unary(
            '/xray.app.proxyman.command.HandlerService/AlterOutbound',
            request_serializer=command_pb.AlterOutboundRequest.SerializeToString,
            response_deserializer=command_pb.AlterOutboundResponse.FromString,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/http/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Dict, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint


@dataclass
class Account(ClassMeta):
    username: Optional[str] = None
    password: Optional[str] = None


@dataclass
class ServerConfig(ClassMeta):
    """Config for HTTP proxy server."""
    accounts: Optional[Dict[str, str]] = None
    allow_transparent: Optional[bool] = None
    user_level: Optional[int] = None


@dataclass
class Header(ClassMeta):
    key: Optional[str] = None
    value: Optional[str] = None


@dataclass
class ClientConfig(ClassMeta):
    """ClientConfig is the protobuf config for HTTP proxy client."""
    server: Optional[List[ServerEndpoint]] = None
    """Sever is a list of HTTP server addresses."""
    header: Optional[List[Header]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\"xcapi/xray/proxy/http/config.proto\x12\x0fxray.proxy.http\x1a,xcapi/xray/common/protocol/server_spec.proto\"-\n\x07\x41\x63\x63ount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xad\x01\n\x0cServerConfig\x12=\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32+.xray.proxy.http.ServerConfig.AccountsEntry\x12\x19\n\x11\x61llow_transparent\x18\x03 \x01(\x08\x12\x12\n\nuser_level\x18\x04 \x01(\r\x1a/\n\rAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x06Header\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"m\n\x0c\x43lientConfig\x12\x34\n\x06server\x18\x01 \x03(\x0b\x32$.xray.common.protocol.ServerEndpoint\x12\'\n\x06header\x18\x02 \x03(\x0b\x32\x17.xray.proxy.http.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.http.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._loaded_options = None
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_options = b'8\001'
    _globals['_ACCOUNT']._serialized_start = 101
    _globals['_ACCOUNT']._serialized_end = 146
    _globals['_SERVERCONFIG']._serialized_start = 149
    _globals['_SERVERCONFIG']._serialized_end = 322
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_start = 275
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_end = 322
    _globals['_HEADER']._serialized_start = 324
    _globals['_HEADER']._serialized_end = 360
    _globals['_CLIENTCONFIG']._serialized_start = 362
    _globals['_CLIENTCONFIG']._serialized_end = 471



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/observatory/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.app.observatory.config_pb import ObservationResult
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class GetOutboundStatusRequest(ClassMeta):
    pass


@dataclass
class GetOutboundStatusResponse(ClassMeta):
    status: Optional[ObservationResult] = None


@dataclass
class Config(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n0xcapi/xray/app/observatory/command/command.proto\x12!xray.core.app.observatory.command\x1a\'xcapi/xray/app/observatory/config.proto\"\x1a\n\x18GetOutboundStatusRequest\"Y\n\x19GetOutboundStatusResponse\x12<\n\x06status\x18\x01 \x01(\x0b\x32,.xray.core.app.observatory.ObservationResult\"\x08\n\x06\x43onfig2\xa7\x01\n\x12ObservatoryService\x12\x90\x01\n\x11GetOutboundStatus\x12;.xray.core.app.observatory.command.GetOutboundStatusRequest\x1a<.xray.core.app.observatory.command.GetOutboundStatusResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.observatory.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETOUTBOUNDSTATUSREQUEST']._serialized_start = 128
    _globals['_GETOUTBOUNDSTATUSREQUEST']._serialized_end = 154
    _globals['_GETOUTBOUNDSTATUSRESPONSE']._serialized_start = 156
    _globals['_GETOUTBOUNDSTATUSRESPONSE']._serialized_end = 245
    _globals['_CONFIG']._serialized_start = 247
    _globals['_CONFIG']._serialized_end = 255
    _globals['_OBSERVATORYSERVICE']._serialized_start = 258
    _globals['_OBSERVATORYSERVICE']._serialized_end = 425



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/headers/srtp/config.proto
"""Generated protocol buffer code."""
from typing import Optional
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    version: Optional[int] = None
    padding: Optional[bool] = None
    extension: Optional[bool] = None
    csrc_count: Optional[int] = None
    marker: Optional[bool] = None
    payload_type: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n7xcapi/xray/transport/internet/headers/srtp/config.proto\x12$xray.transport.internet.headers.srtp\"w\n\x06\x43onfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x0f\n\x07padding\x18\x02 \x01(\x08\x12\x11\n\textension\x18\x03 \x01(\x08\x12\x12\n\ncsrc_count\x18\x04 \x01(\r\x12\x0e\n\x06marker\x18\x05 \x01(\x08\x12\x14\n\x0cpayload_type\x18\x06 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.headers.srtp.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 97
    _globals['_CONFIG']._serialized_end = 216



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/shadowsocks/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from enum import Enum
from xcapi.xray.common.protocol.user_pb import User
from xcapi.xray.common.net.network_pb import Network
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint


class CipherType(Enum):
    UNKNOWN: int = 0
    AES_128_GCM: int = 5
    AES_256_GCM: int = 6
    CHACHA20_POLY1305: int = 7
    XCHACHA20_POLY1305: int = 8
    NONE: int = 9


@dataclass
class Account(ClassMeta):
    password: Optional[str] = None
    cipher_type: Optional[CipherType] = None
    iv_check: Optional[bool] = None


@dataclass
class ServerConfig(ClassMeta):
    users: Optional[List[User]] = None
    network: Optional[List[Network]] = None


@dataclass
class ClientConfig(ClassMeta):
    server: Optional[List[ServerEndpoint]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)xcapi/xray/proxy/shadowsocks/config.proto\x12\x16xray.proxy.shadowsocks\x1a#xcapi/xray/common/net/network.proto\x1a%xcapi/xray/common/protocol/user.proto\x1a,xcapi/xray/common/protocol/server_spec.proto\"f\n\x07\x41\x63\x63ount\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x37\n\x0b\x63ipher_type\x18\x02 \x01(\x0e\x32\".xray.proxy.shadowsocks.CipherType\x12\x10\n\x08iv_check\x18\x03 \x01(\x08\"d\n\x0cServerConfig\x12)\n\x05users\x18\x01 \x03(\x0b\x32\x1a.xray.common.protocol.User\x12)\n\x07network\x18\x02 \x03(\x0e\x32\x18.xray.common.net.Network\"D\n\x0c\x43lientConfig\x12\x34\n\x06server\x18\x01 \x03(\x0b\x32$.xray.common.protocol.ServerEndpoint*t\n\nCipherType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0b\x41\x45S_128_GCM\x10\x05\x12\x0f\n\x0b\x41\x45S_256_GCM\x10\x06\x12\x15\n\x11\x43HACHA20_POLY1305\x10\x07\x12\x16\n\x12XCHACHA20_POLY1305\x10\x08\x12\x08\n\x04NONE\x10\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.shadowsocks.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CIPHERTYPE']._serialized_start = 467
    _globals['_CIPHERTYPE']._serialized_end = 583
    _globals['_ACCOUNT']._serialized_start = 191
    _globals['_ACCOUNT']._serialized_end = 293
    _globals['_SERVERCONFIG']._serialized_start = 295
    _globals['_SERVERCONFIG']._serialized_end = 395
    _globals['_CLIENTCONFIG']._serialized_start = 397
    _globals['_CLIENTCONFIG']._serialized_end = 465



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/trojan/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint
from xcapi.xray.common.protocol.user_pb import User


@dataclass
class Account(ClassMeta):
    password: Optional[str] = None


@dataclass
class Fallback(ClassMeta):
    name: Optional[str] = None
    alpn: Optional[str] = None
    path: Optional[str] = None
    type: Optional[str] = None
    dest: Optional[str] = None
    xver: Optional[int] = None


@dataclass
class ClientConfig(ClassMeta):
    server: Optional[List[ServerEndpoint]] = None


@dataclass
class ServerConfig(ClassMeta):
    users: Optional[List[User]] = None
    fallbacks: Optional[List[Fallback]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$xcapi/xray/proxy/trojan/config.proto\x12\x11xray.proxy.trojan\x1a%xcapi/xray/common/protocol/user.proto\x1a,xcapi/xray/common/protocol/server_spec.proto\"\x1b\n\x07\x41\x63\x63ount\x12\x10\n\x08password\x18\x01 \x01(\t\"^\n\x08\x46\x61llback\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61lpn\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65st\x18\x05 \x01(\t\x12\x0c\n\x04xver\x18\x06 \x01(\x04\"D\n\x0c\x43lientConfig\x12\x34\n\x06server\x18\x01 \x03(\x0b\x32$.xray.common.protocol.ServerEndpoint\"i\n\x0cServerConfig\x12)\n\x05users\x18\x01 \x03(\x0b\x32\x1a.xray.common.protocol.User\x12.\n\tfallbacks\x18\x02 \x03(\x0b\x32\x1b.xray.proxy.trojan.Fallbackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.trojan.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ACCOUNT']._serialized_start = 144
    _globals['_ACCOUNT']._serialized_end = 171
    _globals['_FALLBACK']._serialized_start = 173
    _globals['_FALLBACK']._serialized_end = 267
    _globals['_CLIENTCONFIG']._serialized_start = 269
    _globals['_CLIENTCONFIG']._serialized_end = 337
    _globals['_SERVERCONFIG']._serialized_start = 339
    _globals['_SERVERCONFIG']._serialized_end = 444



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/vless/inbound/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.protocol.user_pb import User


@dataclass
class Fallback(ClassMeta):
    name: Optional[str] = None
    alpn: Optional[str] = None
    path: Optional[str] = None
    type: Optional[str] = None
    dest: Optional[str] = None
    xver: Optional[int] = None


@dataclass
class Config(ClassMeta):
    clients: Optional[List[User]] = None
    """Decryption settings. Only applies to server side, and only accepts "none" for now."""
    decryption: Optional[str] = None
    fallbacks: Optional[List[Fallback]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n+xcapi/xray/proxy/vless/inbound/config.proto\x12\x18xray.proxy.vless.inbound\x1a%xcapi/xray/common/protocol/user.proto\"^\n\x08\x46\x61llback\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61lpn\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65st\x18\x05 \x01(\t\x12\x0c\n\x04xver\x18\x06 \x01(\x04\"\x80\x01\n\x06\x43onfig\x12+\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x1a.xray.common.protocol.User\x12\x12\n\ndecryption\x18\x02 \x01(\t\x12\x35\n\tfallbacks\x18\x03 \x03(\x0b\x32\".xray.proxy.vless.inbound.Fallbackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.vless.inbound.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_FALLBACK']._serialized_start = 112
    _globals['_FALLBACK']._serialized_end = 206
    _globals['_CONFIG']._serialized_start = 209
    _globals['_CONFIG']._serialized_end = 337



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/policy/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Dict
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Second(ClassMeta):
    value: Optional[int] = None


@dataclass
class Policy(ClassMeta):
    @dataclass
    class Timeout(ClassMeta):
        """Timeout is a message for timeout settings in various stages, in seconds."""
        handshake: Optional[Second] = None
        connection_idle: Optional[Second] = None
        uplink_only: Optional[Second] = None
        downlink_only: Optional[Second] = None

    @dataclass
    class Stats(ClassMeta):
        user_uplink: Optional[bool] = None
        user_downlink: Optional[bool] = None

    @dataclass
    class Buffer(ClassMeta):
        connection: Optional[int] = None
        """Buffer size per connection, in bytes. -1 for unlimited buffer."""

    timeout: Optional[Timeout] = None
    stats: Optional[Stats] = None
    buffer: Optional[Buffer] = None


@dataclass
class SystemPolicy(ClassMeta):
    @dataclass
    class Stats(ClassMeta):
        inbound_uplink: Optional[bool] = None
        inbound_downlink: Optional[bool] = None
        outbound_uplink: Optional[bool] = None
        outbound_downlink: Optional[bool] = None

    stats: Optional[Stats] = None


@dataclass
class Config(ClassMeta):
    level: Optional[Dict[int, Policy]] = None
    system: Optional[SystemPolicy] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\"xcapi/xray/app/policy/config.proto\x12\x0fxray.app.policy\"\x17\n\x06Second\x12\r\n\x05value\x18\x01 \x01(\r\"\xb3\x03\n\x06Policy\x12\x30\n\x07timeout\x18\x01 \x01(\x0b\x32\x1f.xray.app.policy.Policy.Timeout\x12,\n\x05stats\x18\x02 \x01(\x0b\x32\x1d.xray.app.policy.Policy.Stats\x12.\n\x06\x62uffer\x18\x03 \x01(\x0b\x32\x1e.xray.app.policy.Policy.Buffer\x1a\xc5\x01\n\x07Timeout\x12*\n\thandshake\x18\x01 \x01(\x0b\x32\x17.xray.app.policy.Second\x12\x30\n\x0f\x63onnection_idle\x18\x02 \x01(\x0b\x32\x17.xray.app.policy.Second\x12,\n\x0buplink_only\x18\x03 \x01(\x0b\x32\x17.xray.app.policy.Second\x12.\n\rdownlink_only\x18\x04 \x01(\x0b\x32\x17.xray.app.policy.Second\x1a\x33\n\x05Stats\x12\x13\n\x0buser_uplink\x18\x01 \x01(\x08\x12\x15\n\ruser_downlink\x18\x02 \x01(\x08\x1a\x1c\n\x06\x42uffer\x12\x12\n\nconnection\x18\x01 \x01(\x05\"\xb1\x01\n\x0cSystemPolicy\x12\x32\n\x05stats\x18\x01 \x01(\x0b\x32#.xray.app.policy.SystemPolicy.Stats\x1am\n\x05Stats\x12\x16\n\x0einbound_uplink\x18\x01 \x01(\x08\x12\x18\n\x10inbound_downlink\x18\x02 \x01(\x08\x12\x17\n\x0foutbound_uplink\x18\x03 \x01(\x08\x12\x19\n\x11outbound_downlink\x18\x04 \x01(\x08\"\xb1\x01\n\x06\x43onfig\x12\x31\n\x05level\x18\x01 \x03(\x0b\x32\".xray.app.policy.Config.LevelEntry\x12-\n\x06system\x18\x02 \x01(\x0b\x32\x1d.xray.app.policy.SystemPolicy\x1a\x45\n\nLevelEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.xray.app.policy.Policy:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.policy.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG_LEVELENTRY']._loaded_options = None
    _globals['_CONFIG_LEVELENTRY']._serialized_options = b'8\001'
    _globals['_SECOND']._serialized_start = 55
    _globals['_SECOND']._serialized_end = 78
    _globals['_POLICY']._serialized_start = 81
    _globals['_POLICY']._serialized_end = 516
    _globals['_POLICY_TIMEOUT']._serialized_start = 236
    _globals['_POLICY_TIMEOUT']._serialized_end = 433
    _globals['_POLICY_STATS']._serialized_start = 435
    _globals['_POLICY_STATS']._serialized_end = 486
    _globals['_POLICY_BUFFER']._serialized_start = 488
    _globals['_POLICY_BUFFER']._serialized_end = 516
    _globals['_SYSTEMPOLICY']._serialized_start = 519
    _globals['_SYSTEMPOLICY']._serialized_end = 696
    _globals['_SYSTEMPOLICY_STATS']._serialized_start = 587
    _globals['_SYSTEMPOLICY_STATS']._serialized_end = 696
    _globals['_CONFIG']._serialized_start = 699
    _globals['_CONFIG']._serialized_end = 876
    _globals['_CONFIG_LEVELENTRY']._serialized_start = 807
    _globals['_CONFIG_LEVELENTRY']._serialized_end = 876



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/observatory/burst/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class HealthPingConfig(ClassMeta):
    destination: Optional[str] = None
    """
    destination url, need 204 for success return
    default https://connectivitycheck.gstatic.com/generate_204
    """
    connectivity: Optional[str] = None
    """connectivity check url"""
    interval: Optional[int] = None
    """health check interval, int64 values of time.Duration"""
    samplingCount: Optional[int] = None
    """sampling count is the amount of recent ping results which are kept for calculation"""
    timeout: Optional[int] = None
    """ping timeout, int64 values of time.Duration"""


@dataclass
class Config(ClassMeta):
    subject_selector: Optional[List[str]] = None
    """The selectors for outbound under observation"""
    ping_config: Optional[HealthPingConfig] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n-xcapi/xray/app/observatory/burst/config.proto\x12\x1fxray.core.app.observatory.burst\"j\n\x06\x43onfig\x12\x18\n\x10subject_selector\x18\x02 \x03(\t\x12\x46\n\x0bping_config\x18\x03 \x01(\x0b\x32\x31.xray.core.app.observatory.burst.HealthPingConfig\"w\n\x10HealthPingConfig\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x14\n\x0c\x63onnectivity\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\x03\x12\x15\n\rsamplingCount\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.observatory.burst.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 82
    _globals['_CONFIG']._serialized_end = 188
    _globals['_HEALTHPINGCONFIG']._serialized_start = 190
    _globals['_HEALTHPINGCONFIG']._serialized_end = 309



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/protocol/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from dataclasses import dataclass
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.model import ClassMeta


@dataclass
class User(ClassMeta):
    """User is a generic user for all protocols."""
    level: Optional[int] = None
    email: Optional[str] = None
    account: Optional[TypedMessage] = None
    """Protocol specific account information. Must be the account proto in one of the proxies."""


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%xcapi/xray/common/protocol/user.proto\x12\x14xray.common.protocol\x1a,xcapi/xray/common/serial/typed_message.proto\"W\n\x04User\x12\r\n\x05level\x18\x01 \x01(\r\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .xray.common.serial.TypedMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.protocol.user_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_USER']._serialized_start = 109
    _globals['_USER']._serialized_end = 196



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/router/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.xray.common.net.port_pb import PortList
from xcapi.xray.common.net.network_pb import Network
from xcapi.model import ClassMeta
from typing import Optional, List, Dict
from dataclasses import dataclass
from enum import Enum


@dataclass
class Domain(ClassMeta):
    """Domain for routing decision."""

    class Type(Enum):
        """Type of domain value."""
        Plain: int = 0
        """The value is used as is."""
        Regex: int = 1
        """The value is used as a regular expression."""
        Domain: int = 2
        """The value is a root domain."""
        Full: int = 3
        """The value is a domain."""

    type: Optional[Type] = None
    """Domain matching type."""
    value: Optional[str] = None
    """Domain value."""

    @dataclass
    class Attribute(ClassMeta):
        key: Optional[str] = None
        bool_value: Optional[bool] = None
        int_value: Optional[int] = None

    attribute: Optional[List[Attribute]] = None
    """Attributes of this domain. May be used for filtering."""


@dataclass
class CIDR(ClassMeta):
    """IP for routing decision, in CIDR form."""
    ip: Optional[bytes] = None
    """IP address, should be either 4 or 16 bytes."""
    prefix: Optional[int] = None
    """Number of leading ones in the network mask."""


@dataclass
class GeoIP(ClassMeta):
    country_code: Optional[str] = None
    cidr: Optional[List[CIDR]] = None
    reverse_match: Optional[bool] = None


@dataclass
class GeoIPList(ClassMeta):
    entry: Optional[List[GeoIP]] = None


@dataclass
class GeoSite(ClassMeta):
    country_code: Optional[str] = None
    domain: Optional[List[Domain]] = None


@dataclass
class GeoSiteList(ClassMeta):
    entry: Optional[List[GeoSite]] = None


@dataclass
class RoutingRule(ClassMeta):
    tag: Optional[str] = None
    """Tag of outbound that this rule is pointing to."""
    balancing_tag: Optional[str] = None
    """Tag of routing balancer."""
    rule_tag: Optional[str] = None
    domain: Optional[List[Domain]] = None
    """List of domains for target domain matching."""
    geoip: Optional[List[GeoIP]] = None
    """
    List of GeoIPs for target IP address matching. If this entry exists, the cidr above will have no effect.
    GeoIP fields with the same country code are supposed to contain exactly same content.
    They will be merged during runtime. For customized GeoIPs, please leave country code empty.
    """
    port_list: Optional[PortList] = None
    """List of ports."""
    networks: Optional[List[Network]] = None
    """List of networks for matching."""
    source_geoip: Optional[List[GeoIP]] = None
    """List of GeoIPs for source IP address matching. If this entry exists, the source_cidr above will have no effect."""
    source_port_list: Optional[PortList] = None
    """List of ports for source port matching."""
    user_email: Optional[List[str]] = None
    inbound_tag: Optional[List[str]] = None
    protocol: Optional[List[str]] = None
    attributes: Optional[Dict[str, str]] = None
    domain_matcher: Optional[str] = None


@dataclass
class BalancingRule(ClassMeta):
    tag: Optional[str] = None
    outbound_selector: Optional[List[str]] = None
    strategy: Optional[str] = None
    strategy_settings: Optional[TypedMessage] = None
    fallback_tag: Optional[str] = None


@dataclass
class StrategyWeight(ClassMeta):
    regexp: Optional[bool] = None
    match: Optional[str] = None
    value: Optional[float] = None


@dataclass
class StrategyLeastLoadConfig(ClassMeta):
    costs: Optional[List[StrategyWeight]] = None
    """weight settings"""
    baselines: Optional[List[int]] = None
    """RTT baselines for selecting, int64 values of time.Duration"""
    expected: Optional[int] = None
    """expected nodes count to select"""
    maxRTT: Optional[int] = None
    """max acceptable rtt, filter away high delay nodes. default 0"""
    tolerance: Optional[float] = None
    """acceptable failure rate"""


@dataclass
class Config(ClassMeta):
    class DomainStrategy(Enum):
        AsIs: int = 0
        """Use domain as is."""
        UseIp: int = 1
        """Always resolve IP for domains."""
        IpIfNonMatch: int = 2
        """Resolve to IP if the domain doesn't match any rules."""
        IpOnDemand: int = 3
        """Resolve to IP if any rule requires IP matching."""

    domain_strategy: Optional[DomainStrategy] = None
    rule: Optional[List[RoutingRule]] = None
    balancing_rule: Optional[List[BalancingRule]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\"xcapi/xray/app/router/config.proto\x12\x0fxray.app.router\x1a,xcapi/xray/common/serial/typed_message.proto\x1a xcapi/xray/common/net/port.proto\x1a#xcapi/xray/common/net/network.proto\"\x81\x02\n\x06\x44omain\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.xray.app.router.Domain.Type\x12\r\n\x05value\x18\x02 \x01(\t\x12\x34\n\tattribute\x18\x03 \x03(\x0b\x32!.xray.app.router.Domain.Attribute\x1aR\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x42\r\n\x0btyped_value\"2\n\x04Type\x12\t\n\x05Plain\x10\x00\x12\t\n\x05Regex\x10\x01\x12\n\n\x06\x44omain\x10\x02\x12\x08\n\x04\x46ull\x10\x03\"\"\n\x04\x43IDR\x12\n\n\x02ip\x18\x01 \x01(\x0c\x12\x0e\n\x06prefix\x18\x02 \x01(\r\"Y\n\x05GeoIP\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12#\n\x04\x63idr\x18\x02 \x03(\x0b\x32\x15.xray.app.router.CIDR\x12\x15\n\rreverse_match\x18\x03 \x01(\x08\"2\n\tGeoIPList\x12%\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x16.xray.app.router.GeoIP\"H\n\x07GeoSite\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\'\n\x06\x64omain\x18\x02 \x03(\x0b\x32\x17.xray.app.router.Domain\"6\n\x0bGeoSiteList\x12\'\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x18.xray.app.router.GeoSite\"\xaa\x04\n\x0bRoutingRule\x12\r\n\x03tag\x18\x01 \x01(\tH\x00\x12\x17\n\rbalancing_tag\x18\x0c \x01(\tH\x00\x12\x10\n\x08rule_tag\x18\x12 \x01(\t\x12\'\n\x06\x64omain\x18\x02 \x03(\x0b\x32\x17.xray.app.router.Domain\x12%\n\x05geoip\x18\n \x03(\x0b\x32\x16.xray.app.router.GeoIP\x12,\n\tport_list\x18\x0e \x01(\x0b\x32\x19.xray.common.net.PortList\x12*\n\x08networks\x18\r \x03(\x0e\x32\x18.xray.common.net.Network\x12,\n\x0csource_geoip\x18\x0b \x03(\x0b\x32\x16.xray.app.router.GeoIP\x12\x33\n\x10source_port_list\x18\x10 \x01(\x0b\x32\x19.xray.common.net.PortList\x12\x12\n\nuser_email\x18\x07 \x03(\t\x12\x13\n\x0binbound_tag\x18\x08 \x03(\t\x12\x10\n\x08protocol\x18\t \x03(\t\x12@\n\nattributes\x18\x0f \x03(\x0b\x32,.xray.app.router.RoutingRule.AttributesEntry\x12\x16\n\x0e\x64omain_matcher\x18\x11 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\ntarget_tag\"\x9c\x01\n\rBalancingRule\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x19\n\x11outbound_selector\x18\x02 \x03(\t\x12\x10\n\x08strategy\x18\x03 \x01(\t\x12;\n\x11strategy_settings\x18\x04 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x14\n\x0c\x66\x61llback_tag\x18\x05 \x01(\t\">\n\x0eStrategyWeight\x12\x0e\n\x06regexp\x18\x01 \x01(\x08\x12\r\n\x05match\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x02\"\x91\x01\n\x17StrategyLeastLoadConfig\x12.\n\x05\x63osts\x18\x02 \x03(\x0b\x32\x1f.xray.app.router.StrategyWeight\x12\x11\n\tbaselines\x18\x03 \x03(\x03\x12\x10\n\x08\x65xpected\x18\x04 \x01(\x05\x12\x0e\n\x06maxRTT\x18\x05 \x01(\x03\x12\x11\n\ttolerance\x18\x06 \x01(\x02\"\xf6\x01\n\x06\x43onfig\x12?\n\x0f\x64omain_strategy\x18\x01 \x01(\x0e\x32&.xray.app.router.Config.DomainStrategy\x12*\n\x04rule\x18\x02 \x03(\x0b\x32\x1c.xray.app.router.RoutingRule\x12\x36\n\x0e\x62\x61lancing_rule\x18\x03 \x03(\x0b\x32\x1e.xray.app.router.BalancingRule\"G\n\x0e\x44omainStrategy\x12\x08\n\x04\x41sIs\x10\x00\x12\t\n\x05UseIp\x10\x01\x12\x10\n\x0cIpIfNonMatch\x10\x02\x12\x0e\n\nIpOnDemand\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.router.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ROUTINGRULE_ATTRIBUTESENTRY']._loaded_options = None
    _globals['_ROUTINGRULE_ATTRIBUTESENTRY']._serialized_options = b'8\001'
    _globals['_DOMAIN']._serialized_start = 173
    _globals['_DOMAIN']._serialized_end = 430
    _globals['_DOMAIN_ATTRIBUTE']._serialized_start = 296
    _globals['_DOMAIN_ATTRIBUTE']._serialized_end = 378
    _globals['_DOMAIN_TYPE']._serialized_start = 380
    _globals['_DOMAIN_TYPE']._serialized_end = 430
    _globals['_CIDR']._serialized_start = 432
    _globals['_CIDR']._serialized_end = 466
    _globals['_GEOIP']._serialized_start = 468
    _globals['_GEOIP']._serialized_end = 557
    _globals['_GEOIPLIST']._serialized_start = 559
    _globals['_GEOIPLIST']._serialized_end = 609
    _globals['_GEOSITE']._serialized_start = 611
    _globals['_GEOSITE']._serialized_end = 683
    _globals['_GEOSITELIST']._serialized_start = 685
    _globals['_GEOSITELIST']._serialized_end = 739
    _globals['_ROUTINGRULE']._serialized_start = 742
    _globals['_ROUTINGRULE']._serialized_end = 1296
    _globals['_ROUTINGRULE_ATTRIBUTESENTRY']._serialized_start = 1233
    _globals['_ROUTINGRULE_ATTRIBUTESENTRY']._serialized_end = 1282
    _globals['_BALANCINGRULE']._serialized_start = 1299
    _globals['_BALANCINGRULE']._serialized_end = 1455
    _globals['_STRATEGYWEIGHT']._serialized_start = 1457
    _globals['_STRATEGYWEIGHT']._serialized_end = 1519
    _globals['_STRATEGYLEASTLOADCONFIG']._serialized_start = 1522
    _globals['_STRATEGYLEASTLOADCONFIG']._serialized_end = 1667
    _globals['_CONFIG']._serialized_start = 1670
    _globals['_CONFIG']._serialized_end = 1916
    _globals['_CONFIG_DOMAINSTRATEGY']._serialized_start = 1845
    _globals['_CONFIG_DOMAINSTRATEGY']._serialized_end = 1916



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.log.command import config_pb


class LoggerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RestartLogger = channel.unary_unary(
                '/xray.app.log.command.LoggerService/RestartLogger',
                request_serializer=config_pb.RestartLoggerRequest.SerializeToString,
                response_deserializer=config_pb.RestartLoggerResponse.FromString,
                _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/log/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.log.log_pb import Severity
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass
from enum import Enum


@dataclass
class LogType(Enum):
    Nil: int = 0
    """None"""
    Console: int = 1
    File: int = 2
    Event: int = 3


class Config(ClassMeta):
    error_log_type: Optional[LogType] = None
    error_log_level: Optional[Severity] = None
    error_log_path: Optional[str] = None
    access_log_type: Optional[LogType] = None
    access_log_path: Optional[str] = None
    enable_dns_log: Optional[bool] = None
    mask_address: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fxcapi/xray/app/log/config.proto\x12\x0cxray.app.log\x1a\x1fxcapi/xray/common/log/log.proto\"\xfa\x01\n\x06\x43onfig\x12-\n\x0e\x65rror_log_type\x18\x01 \x01(\x0e\x32\x15.xray.app.log.LogType\x12\x32\n\x0f\x65rror_log_level\x18\x02 \x01(\x0e\x32\x19.xray.common.log.Severity\x12\x16\n\x0e\x65rror_log_path\x18\x03 \x01(\t\x12.\n\x0f\x61\x63\x63\x65ss_log_type\x18\x04 \x01(\x0e\x32\x15.xray.app.log.LogType\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x05 \x01(\t\x12\x16\n\x0e\x65nable_dns_log\x18\x06 \x01(\x08\x12\x14\n\x0cmask_address\x18\x07 \x01(\t*5\n\x07LogType\x12\x08\n\x04None\x10\x00\x12\x0b\n\x07\x43onsole\x10\x01\x12\x08\n\x04\x46ile\x10\x02\x12\t\n\x05\x45vent\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.log.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_LOGTYPE']._serialized_start = 335
    _globals['_LOGTYPE']._serialized_end = 388
    _globals['_CONFIG']._serialized_start = 83
    _globals['_CONFIG']._serialized_end = 333



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/grpc/encoding/stream.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Hunk(ClassMeta):
    data: Optional[bytes] = None


@dataclass
class MultiHunk(ClassMeta):
    data: Optional[List[bytes]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n8xcapi/xray/transport/internet/grpc/encoding/stream.proto\x12%xray.transport.internet.grpc.encoding\"\x14\n\x04Hunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x19\n\tMultiHunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\x32\xe6\x01\n\x0bGRPCService\x12\x63\n\x03Tun\x12+.xray.transport.internet.grpc.encoding.Hunk\x1a+.xray.transport.internet.grpc.encoding.Hunk(\x01\x30\x01\x12r\n\x08TunMulti\x12\x30.xray.transport.internet.grpc.encoding.MultiHunk\x1a\x30.xray.transport.internet.grpc.encoding.MultiHunk(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.grpc.encoding.stream_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_HUNK']._serialized_start = 99
    _globals['_HUNK']._serialized_end = 119
    _globals['_MULTIHUNK']._serialized_start = 121
    _globals['_MULTIHUNK']._serialized_end = 146
    _globals['_GRPCSERVICE']._serialized_start = 149
    _globals['_GRPCSERVICE']._serialized_end = 379



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/stats/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class GetStatsRequest(ClassMeta):
    name: Optional[str] = None
    """Name of the stat counter."""
    reset: Optional[bool] = None
    """Whether or not to reset the counter to fetching its value."""


@dataclass
class Stat(ClassMeta):
    name: Optional[str] = None
    value: Optional[int] = None


@dataclass
class GetStatsResponse(ClassMeta):
    stat: Optional[Stat] = None


@dataclass
class QueryStatsRequest(ClassMeta):
    pattern: Optional[str] = None
    reset: Optional[bool] = None


@dataclass
class QueryStatsResponse(ClassMeta):
    stat: Optional[List[Stat]] = None


@dataclass
class SysStatsRequest(ClassMeta):
    pass


@dataclass
class SysStatsResponse(ClassMeta):
    NumGoroutine: Optional[int] = None
    NumGC: Optional[int] = None
    Alloc: Optional[int] = None
    TotalAlloc: Optional[int] = None
    Sys: Optional[int] = None
    Mallocs: Optional[int] = None
    Frees: Optional[int] = None
    LiveObjects: Optional[int] = None
    PauseTotalNs: Optional[int] = None
    Uptime: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*xcapi/xray/app/stats/command/command.proto\x12\x16xray.app.stats.command\".\n\x0fGetStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05reset\x18\x02 \x01(\x08\"#\n\x04Stat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\">\n\x10GetStatsResponse\x12*\n\x04stat\x18\x01 \x01(\x0b\x32\x1c.xray.app.stats.command.Stat\"3\n\x11QueryStatsRequest\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12\r\n\x05reset\x18\x02 \x01(\x08\"@\n\x12QueryStatsResponse\x12*\n\x04stat\x18\x01 \x03(\x0b\x32\x1c.xray.app.stats.command.Stat\"\x11\n\x0fSysStatsRequest\"\xc2\x01\n\x10SysStatsResponse\x12\x14\n\x0cNumGoroutine\x18\x01 \x01(\r\x12\r\n\x05NumGC\x18\x02 \x01(\r\x12\r\n\x05\x41lloc\x18\x03 \x01(\x04\x12\x12\n\nTotalAlloc\x18\x04 \x01(\x04\x12\x0b\n\x03Sys\x18\x05 \x01(\x04\x12\x0f\n\x07Mallocs\x18\x06 \x01(\x04\x12\r\n\x05\x46rees\x18\x07 \x01(\x04\x12\x13\n\x0bLiveObjects\x18\x08 \x01(\x04\x12\x14\n\x0cPauseTotalNs\x18\t \x01(\x04\x12\x0e\n\x06Uptime\x18\n \x01(\r\"\x08\n\x06\x43onfig2\xba\x02\n\x0cStatsService\x12_\n\x08GetStats\x12\'.xray.app.stats.command.GetStatsRequest\x1a(.xray.app.stats.command.GetStatsResponse\"\x00\x12\x65\n\nQueryStats\x12).xray.app.stats.command.QueryStatsRequest\x1a*.xray.app.stats.command.QueryStatsResponse\"\x00\x12\x62\n\x0bGetSysStats\x12\'.xray.app.stats.command.SysStatsRequest\x1a(.xray.app.stats.command.SysStatsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.stats.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETSTATSREQUEST']._serialized_start = 70
    _globals['_GETSTATSREQUEST']._serialized_end = 116
    _globals['_STAT']._serialized_start = 118
    _globals['_STAT']._serialized_end = 153
    _globals['_GETSTATSRESPONSE']._serialized_start = 155
    _globals['_GETSTATSRESPONSE']._serialized_end = 217
    _globals['_QUERYSTATSREQUEST']._serialized_start = 219
    _globals['_QUERYSTATSREQUEST']._serialized_end = 270
    _globals['_QUERYSTATSRESPONSE']._serialized_start = 272
    _globals['_QUERYSTATSRESPONSE']._serialized_end = 336
    _globals['_SYSSTATSREQUEST']._serialized_start = 338
    _globals['_SYSSTATSREQUEST']._serialized_end = 355
    _globals['_SYSSTATSRESPONSE']._serialized_start = 358
    _globals['_SYSSTATSRESPONSE']._serialized_end = 552
    _globals['_CONFIG']._serialized_start = 554
    _globals['_CONFIG']._serialized_end = 562
    _globals['_STATSSERVICE']._serialized_start = 565
    _globals['_STATSSERVICE']._serialized_end = 879



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/dokodemo/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.net.network_pb import Network
from xcapi.xray.common.net.address_pb import IPOrDomain


@dataclass
class Config(ClassMeta):
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None
    networks: Optional[List[Network]] = None
    """List of networks that the Dokodemo accepts"""
    follow_redirect: Optional[bool] = None
    user_level: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&xcapi/xray/proxy/dokodemo/config.proto\x12\x13xray.proxy.dokodemo\x1a#xcapi/xray/common/net/address.proto\x1a#xcapi/xray/common/net/network.proto\"\x9d\x01\n\x06\x43onfig\x12,\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x02 \x01(\r\x12*\n\x08networks\x18\x07 \x03(\x0e\x32\x18.xray.common.net.Network\x12\x17\n\x0f\x66ollow_redirect\x18\x05 \x01(\x08\x12\x12\n\nuser_level\x18\x06 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.dokodemo.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 138
    _globals['_CONFIG']._serialized_end = 295



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/kcp/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class MTU(ClassMeta):
    """Maximum Transmission Unit, in bytes."""
    value: Optional[int] = None


@dataclass
class TTI(ClassMeta):
    """Transmission Time Interview, in milli-sec."""
    value: Optional[int] = None


@dataclass
class UplinkCapacity(ClassMeta):
    """Uplink capacity, in MB."""
    value: Optional[int] = None


@dataclass
class DownlinkCapacity(ClassMeta):
    """Downlink capacity, in MB."""
    value: Optional[int] = None


@dataclass
class WriteBuffer(ClassMeta):
    size: Optional[int] = None
    """Buffer size in bytes."""


@dataclass
class ReadBuffer(ClassMeta):
    size: Optional[int] = None
    """Buffer size in bytes."""


@dataclass
class ConnectionReuse(ClassMeta):
    enable: Optional[bool] = None


@dataclass
class EncryptionSeed(ClassMeta):
    """Maximum Transmission Unit, in bytes."""
    seed: Optional[str] = None


@dataclass
class Config(ClassMeta):
    mtu: Optional[MTU] = None
    tti: Optional[TTI] = None
    uplink_capacity: Optional[UplinkCapacity] = None
    downlink_capacity: Optional[DownlinkCapacity] = None
    congestion: Optional[bool] = None
    write_buffer: Optional[WriteBuffer] = None
    read_buffer: Optional[ReadBuffer] = None
    header_config: Optional[TypedMessage] = None
    seed: Optional[EncryptionSeed] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n.xcapi/xray/transport/internet/kcp/config.proto\x12\x1bxray.transport.internet.kcp\x1a,xcapi/xray/common/serial/typed_message.proto\"\x14\n\x03MTU\x12\r\n\x05value\x18\x01 \x01(\r\"\x14\n\x03TTI\x12\r\n\x05value\x18\x01 \x01(\r\"\x1f\n\x0eUplinkCapacity\x12\r\n\x05value\x18\x01 \x01(\r\"!\n\x10\x44ownlinkCapacity\x12\r\n\x05value\x18\x01 \x01(\r\"\x1b\n\x0bWriteBuffer\x12\x0c\n\x04size\x18\x01 \x01(\r\"\x1a\n\nReadBuffer\x12\x0c\n\x04size\x18\x01 \x01(\r\"!\n\x0f\x43onnectionReuse\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"\x1e\n\x0e\x45ncryptionSeed\x12\x0c\n\x04seed\x18\x01 \x01(\t\"\x82\x04\n\x06\x43onfig\x12-\n\x03mtu\x18\x01 \x01(\x0b\x32 .xray.transport.internet.kcp.MTU\x12-\n\x03tti\x18\x02 \x01(\x0b\x32 .xray.transport.internet.kcp.TTI\x12\x44\n\x0fuplink_capacity\x18\x03 \x01(\x0b\x32+.xray.transport.internet.kcp.UplinkCapacity\x12H\n\x11\x64ownlink_capacity\x18\x04 \x01(\x0b\x32-.xray.transport.internet.kcp.DownlinkCapacity\x12\x12\n\ncongestion\x18\x05 \x01(\x08\x12>\n\x0cwrite_buffer\x18\x06 \x01(\x0b\x32(.xray.transport.internet.kcp.WriteBuffer\x12<\n\x0bread_buffer\x18\x07 \x01(\x0b\x32\'.xray.transport.internet.kcp.ReadBuffer\x12\x37\n\rheader_config\x18\x08 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x39\n\x04seed\x18\n \x01(\x0b\x32+.xray.transport.internet.kcp.EncryptionSeedJ\x04\x08\t\x10\nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.kcp.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_MTU']._serialized_start = 125
    _globals['_MTU']._serialized_end = 145
    _globals['_TTI']._serialized_start = 147
    _globals['_TTI']._serialized_end = 167
    _globals['_UPLINKCAPACITY']._serialized_start = 169
    _globals['_UPLINKCAPACITY']._serialized_end = 200
    _globals['_DOWNLINKCAPACITY']._serialized_start = 202
    _globals['_DOWNLINKCAPACITY']._serialized_end = 235
    _globals['_WRITEBUFFER']._serialized_start = 237
    _globals['_WRITEBUFFER']._serialized_end = 264
    _globals['_READBUFFER']._serialized_start = 266
    _globals['_READBUFFER']._serialized_end = 292
    _globals['_CONNECTIONREUSE']._serialized_start = 294
    _globals['_CONNECTIONREUSE']._serialized_end = 327
    _globals['_ENCRYPTIONSEED']._serialized_start = 329
    _globals['_ENCRYPTIONSEED']._serialized_end = 359
    _globals['_CONFIG']._serialized_start = 362
    _globals['_CONFIG']._serialized_end = 876



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/log/log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from enum import Enum


class Severity(Enum):
    Unknown: int = 0
    Error: int = 1
    Warning: int = 2
    Info: int = 3
    Debug: int = 4


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fxcapi/xray/common/log/log.proto\x12\x0fxray.common.log*D\n\x08Severity\x12\x0b\n\x07Unknown\x10\x00\x12\t\n\x05\x45rror\x10\x01\x12\x0b\n\x07Warning\x10\x02\x12\x08\n\x04Info\x10\x03\x12\t\n\x05\x44\x65\x62ug\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.log.log_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SEVERITY']._serialized_start = 52
    _globals['_SEVERITY']._serialized_end = 120



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/headers/wireguard/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class WireguardConfig(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n<xcapi/xray/transport/internet/headers/wireguard/config.proto\x12)xray.transport.internet.headers.wireguard\"\x11\n\x0fWireguardConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.headers.wireguard.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_WIREGUARDCONFIG']._serialized_start = 107
    _globals['_WIREGUARDCONFIG']._serialized_end = 124



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/net/destination.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.network_pb import Network
from xcapi.xray.common.net.address_pb import IPOrDomain
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass


@dataclass
class Endpoint(ClassMeta):
    """Endpoint of a network connection."""
    network: Optional[Network] = None
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/common/net/destination.proto\x12\x0fxray.common.net\x1a#xcapi/xray/common/net/network.proto\x1a#xcapi/xray/common/net/address.proto\"q\n\x08\x45ndpoint\x12)\n\x07network\x18\x01 \x01(\x0e\x32\x18.xray.common.net.Network\x12,\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.net.destination_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ENDPOINT']._serialized_start = 134
    _globals['_ENDPOINT']._serialized_end = 247
